# Pure Storage Unified Python SDK

## Overview

The `py-pure-client` Python package provides clients that use the Pure1 1.x REST API
and the FlashArray REST 2.x API.

For the current FlashBlade REST 1.x Python SDK, [see here](https://github.com/purestorage/purity_fb_python_client).
For the current FlashArray REST 1.x Python SDK, [see here](https://github.com/PureStorage-OpenConnect/rest-client).

## Requirements

The library requires Python 2.7 and higher or Python 3.3 and higher. Third-party
libraries are also required.

## Installation

### pip Installation
For Python 2.x:
```
$ pip install py-pure-client
```
For Python 3.x:
```
$ pip3 install py-pure-client
```

### Manual Installation
```
$ git clone https://github.com/PureStorage-OpenConnect/py-pure-client.git
$ cd py-pure-client
$ pip install -r requirements.txt
$ python setup.py install
```

## Documentation

For full documentation, including a quick start guide and examples, see https://pure-storage-py-pure-client.readthedocs-hosted.com/en/latest/index.html.
